@@ -385,7 +385,7 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Enable Losseless Compression</source>
+        <source>Enable Lossless Compression</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -967,6 +967,10 @@ Kattintson megszakítás gombra, hogy az összes műveletet megszakísta.</trans
         <source>Analyzing the file. It may take a while, please wait...</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Converted</source>
+        <translation type="unfinished">Átalakított</translation>
+    </message>
 </context>
 <context>
     <name>PixTreeWidget</name>
