@@ -377,42 +377,46 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Jpeg</source>
-        <translation type="unfinished"></translation>
+        <translation>Jpeg</translation>
     </message>
     <message>
         <source>Png/Mng</source>
-        <translation type="unfinished"></translation>
+        <translation>Png/Mng</translation>
     </message>
     <message>
         <source>WebP</source>
-        <translation type="unfinished"></translation>
+        <translation>WebP</translation>
     </message>
     <message>
         <source>WebP General Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>WebP Genel Ayarlar</translation>
     </message>
     <message>
         <source>Enable Losseless Compression</source>
-        <translation type="unfinished"></translation>
+        <translation type="vanished">Kayıpsız Sıkıştırmayı Etkinleştir</translation>
     </message>
     <message>
         <source>Compression Method:</source>
-        <translation type="unfinished"></translation>
+        <translation>Sıkıştırma Yöntemi:</translation>
     </message>
     <message>
         <source>Quality:</source>
-        <translation type="unfinished"></translation>
+        <translation>Kalite:</translation>
     </message>
     <message>
         <source>%</source>
-        <translation type="unfinished"></translation>
+        <translation>%</translation>
     </message>
     <message>
         <source>Enable Dithering</source>
-        <translation type="unfinished"></translation>
+        <translation>Titremeyi Etkinleştir</translation>
     </message>
     <message>
         <source>Remove image&apos;s metadata</source>
+        <translation>Görüntülerin üst verilerini kaldır</translation>
+    </message>
+    <message>
+        <source>Enable Lossless Compression</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -976,6 +980,10 @@ Tüm işlemleri iptal etmek için Vazgeç&apos;e tıklayın.</translation>
         <source>Analyzing the file. It may take a while, please wait...</source>
         <translation>Dosya inceleniyor. Biraz zaman alabilir, lütfen bekleyin...</translation>
     </message>
+    <message>
+        <source>Converted</source>
+        <translation>Dönüştürüldü</translation>
+    </message>
 </context>
 <context>
     <name>PixTreeWidget</name>
