@@ -2,7 +2,7 @@
 * This file is part of Converseen, an open-source batch image converter
 * and resizer.
 *
-* (C) Francesco Mondello 2009 - 2022
+* (C) Francesco Mondello 2009 - 2023
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -39,6 +39,8 @@ public:
         QList<QPair<QString, QString> > loadTranslationFiles();
         QString currentLanguage();
         QString loadCurrentTranslationName();
+        QString findLangDir();
+        bool qmFilesFound(const QString &path);
 private:
         QSettings *settings;
 		QString m_loc;
